***************************
Pipeline (`skypy.pipeline`)
***************************

.. currentmodule:: skypy.pipeline


Running SkyPy
=============

The `~skypy.pipeline` package contains the functionality to run a SkyPy
simulation from end to end. This is implemented in the `~driver.SkyPyDriver`
class and can be called using the command line script
`~skypy.pipeline.scripts.skypy`.


Reference/API
=============

.. automodapi:: skypy.pipeline
.. automodapi:: skypy.pipeline.driver
.. automodapi:: skypy.pipeline.scripts.skypy
